@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //*************************************************************************
 //
-// Copyright 2000-2012 by Wilson Snyder.  This program is free software;
+// Copyright 2000-2013 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 //
@@ -208,28 +208,29 @@ public:
 		"eventually","expect","export","extends","extern","final","first_match",
 		"for","force","foreach","forever","fork","forkjoin","function",
 		"generate","genvar","global","highz0","highz1","if","iff",
-		"ifnone","ignore_bins","illegal_bins","implies","import","incdir","include",
-		"initial","inout","input","inside","instance","int","integer",
-		"interface","intersect","join","join_any","join_none","large","let",
-		"liblist","library","local","localparam","logic","longint","macromodule",
-		"matches","medium","modport","module","nand","negedge","new",
-		"nexttime","nmos","nor","noshowcancelled","not","notif0","notif1",
-		"null","or","output","package","packed","parameter","pmos",
-		"posedge","primitive","priority","program","property","protected","pull0",
-		"pull1","pulldown","pullup","pulsestyle_ondetect","pulsestyle_onevent","pure","rand",
-		"randc","randcase","randsequence","rcmos","real","realtime","ref",
-		"reg","reject_on","release","repeat","restrict","return","rnmos",
-		"rpmos","rtran","rtranif0","rtranif1","s_always","s_eventually","s_nexttime",
-		"s_until","s_until_with","scalared","sequence","shortint","shortreal","showcancelled",
-		"signed","small","solve","specify","specparam","static","strength",
-		"string","strong","strong0","strong1","struct","super","supply0",
-		"supply1","sync_accept_on","sync_reject_on","table","tagged","task","this",
-		"throughout","time","timeprecision","timeunit","tran","tranif0","tranif1",
-		"tri","tri0","tri1","triand","trior","trireg","type",
-		"typedef","union","unique","unique0","unsigned","until","until_with",
-		"untyped","use","uwire","var","vectored","virtual","void",
-		"wait","wait_order","wand","weak","weak0","weak1","while",
-		"wildcard","wire","with","within","wor","xnor","xor",""};
+		"ifnone","ignore_bins","illegal_bins","implements","implies","import","incdir",
+		"include","initial","inout","input","inside","instance","int",
+		"integer","interconnect","interface","intersect","join","join_any","join_none",
+		"large","let","liblist","library","local","localparam","logic",
+		"longint","macromodule","matches","medium","modport","module","nand",
+		"negedge","nettype","new","nexttime","nmos","nor","noshowcancelled",
+		"not","notif0","notif1","null","or","output","package",
+		"packed","parameter","pmos","posedge","primitive","priority","program",
+		"property","protected","pull0","pull1","pulldown","pullup","pulsestyle_ondetect",
+		"pulsestyle_onevent","pure","rand","randc","randcase","randsequence","rcmos",
+		"real","realtime","ref","reg","reject_on","release","repeat",
+		"restrict","return","rnmos","rpmos","rtran","rtranif0","rtranif1",
+		"s_always","s_eventually","s_nexttime","s_until","s_until_with","scalared","sequence",
+		"shortint","shortreal","showcancelled","signed","small","soft","solve",
+		"specify","specparam","static","strength","string","strong","strong0",
+		"strong1","struct","super","supply0","supply1","sync_accept_on","sync_reject_on",
+		"table","tagged","task","this","throughout","time","timeprecision",
+		"timeunit","tran","tranif0","tranif1","tri","tri0","tri1",
+		"triand","trior","trireg","type","typedef","union","unique",
+		"unique0","unsigned","until","until_with","untyped","use","uwire",
+		"var","vectored","virtual","void","wait","wait_order","wand",
+		"weak","weak0","weak1","while","wildcard","wire","with",
+		"within","wor","xnor","xor",""};
 	    for (const char** k=kwds; **k; k++) s_map.insert(*k);
 	}
 	string str(kwd,leng);
